---
title: "getDateFormatter"
parent: "@messageformat/date-skeleton"
grand_parent: API Reference
---

<!-- Do not edit this file. It is automatically generated by API Documenter. -->



# getDateFormatter() function

Returns a date formatter function for the given locales and date skeleton

<b>Signature:</b>

```typescript
export declare function getDateFormatter(locales: string | string[], tokens: string | DateToken[], onError?: (error: DateFormatError) => void): (date: Date | number) => string;
```

## Parameters

|  Parameter | Type | Description |
|  --- | --- | --- |
|  locales | string \| string\[\] | One or more valid BCP 47 language tags, e.g. <code>fr</code> or <code>en-CA</code> |
|  tokens | string \| [DateToken](./date-skeleton.datetoken.md)<!-- -->\[\] | An ICU DateFormat skeleton string, or an array or parsed <code>DateToken</code> tokens |
|  onError | (error: [DateFormatError](./date-skeleton.dateformaterror.md)<!-- -->) =&gt; void | <i>(Optional)</i> If defined, will be called separately for each encountered parsing error and unsupported feature. |

<b>Returns:</b>

(date: Date \| number) =&gt; string

## Remarks

Uses `Intl.DateTimeFormat` internally.

## Example


```js
import { getDateFormatter } from '@messageformat/date-skeleton'

// 2006 Jan 2, 15:04:05.789 in local time
const date = new Date(2006, 0, 2, 15, 4, 5, 789)

let fmt = getDateFormatter('en-CA', 'GrMMMdd', console.error)
fmt(date) // 'Jan. 02, 2006 AD'

fmt = getDateFormatter('en-CA', 'hamszzzz', console.error)
fmt(date) // '3:04:05 p.m. Newfoundland Daylight Time'
```

